@@ -11,25 +11,22 @@ wine[5, ]
 ## ----sample, warning = FALSE, message = FALSE----------------------------
 wine_svm <- e1071::svm(quality ~., data = wine)
 
-similar <- sample_locally(data = wine,
+similar <- sample_locally2(data = wine,
                           explained_instance = wine[5, ],
                           explained_var = "quality",
                           size = 500)
 
 ## ----add, warning = FALSE, message = FALSE-------------------------------
-similar1 <- add_predictions(data = wine,
-                           to_explain = similar,
-                           black_box_model = wine_svm)
+similar1 <- add_predictions2(to_explain = similar,
+                            black_box_model = wine_svm)
 
 ## ----explanation, warning = FALSE, message = FALSE-----------------------
-wine_expl <- fit_explanation(live_object = similar1,
+wine_expl <- fit_explanation2(live_object = similar1,
                              white_box = "regr.lm")
 
 ## ----forestplot, warning = FALSE, message = FALSE, fig.width = 7---------
-plot_explanation(model = wine_expl, regr_plot_type = "forestplot",
-                 explained_instance = wine[5, ])
+plot_explanation2(wine_expl, "forest")
 
 ## ----waterfallplot, warning = FALSE, message = FALSE, fig.width = 7------
-plot_explanation(model = wine_expl, regr_plot_type = "waterfallplot",
-                 explained_instance = wine[5, ])
+plot_explanation2(wine_expl, "waterfall")
 
